# Abaqus Model Database

Mdb commands are used to create and upgrade an Abaqus model database that stores models and analysis controls.

```{toctree}
:caption: Objects in Mdb
:maxdepth: 1

model/index
job
annotation
edit_mesh
```

## Classes

### Mdb

```{eval-rst}
.. autoclass:: abaqus.Mdb.Mdb.Mdb
   :members:
   :show-inheritance:

   .. autoclasstoc::
```

### Other Classes

```{eval-rst}

.. toggle::

   .. automembers:: abaqus.Mdb
      :recursive:
      :exclude: Mdb

   .. placeholder for empty members
```
